#!/bin/sh
#------------------------------------------------------------------------------
# /tmp/install.sh - installation file for mini_httpd module
#
# Copyright (c) 2004-2010  Marcus Herleb, herleb(at)herleb(dot)de
# Copyright (c) 2011-2018  The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2004-01-01 mh
# Last Update:  $Id: install.sh 52314 2018-03-11 16:25:49Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version..
#------------------------------------------------------------------------------

# include eislib etc.
. /var/install/include/eislib
. /var/install/include/jedlib

# set variables
module_name='mini_httpd_unimount'

mini_httpd_path=/usr/local/htdocs

myecho --pack ${module_name} --info "running install.sh ..."

# update shared library file
update_jedlib ${module_name}

myecho --pack ${module_name} "adding menu ..."
/var/install/bin/add-menu --menu "setup.services.mini_httpd.module.menu" \
    "setup.services.mini_httpd.module.${module_name}.menu" "Unimount - Universal Mounter"

# menue entry does not exist - create it
myecho --pack ${module_name} "adding ${module_name} module menu ..."

# delete menu entries (if already exist)
for CGINAME in ./unimount/unimount.cgi ./unimount/unimount.html
do
    /usr/local/bin/httpd-menu.sh rem "${CGINAME}"
done

# make menu entry (to update old installations)
if [ -f ${mini_httpd_path}/unimount/unimount.html ]
then
    /usr/local/bin/httpd-menu.sh add "./unimount/unimount.html" "Unimount" "Tools"
fi

# check directories and files
myecho --pack ${module_name} "setting file/directory access rights ..."

chmod -R 550 ${mini_httpd_path}/unimount/*.cgi
chmod -R 550 ${mini_httpd_path}/unimount/*.sh

# rename log file
if [ -f /var/log/log.admin ]
then
    mv /var/log/log.admin /var/log/log.unimount
fi

# install/update package configuration file
silent=''
if called_from_install --pack "${module_name}"
then
    silent='--quiet'
fi

update=false
if install_config ${silent} ${module_name}
then
    update=true
fi

# configuration
myecho --pack ${module_name} "creating ${module_name} configuration ..."

if [ "${update}" = "true" ]
then
    # updated installation
    /var/install/config.d/${module_name}.sh
    if [ -f /etc/init.d/${module_name} ]
    then
        /etc/init.d/${module_name} restart
    fi
else
    # new installation
    /var/install/bin/edit --apply "${module_name}" "Edit ${module_name} services configuration"
fi

exit 0
