#!/bin/sh
#------------------------------------------------------------------------------
# /tmp/preinstall.sh - pre-installation file for mini_httpd module
#
# Copyright (c) 2004-2010  Marcus Herleb, herleb(at)herleb(dot)de
# Copyright (c) 2011-2018  The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2004-01-01 mh
# Last Update:  $Id: preinstall.sh 52314 2018-03-11 16:25:49Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version..
#------------------------------------------------------------------------------

old_module_name='unimount'
module_name='mini_httpd_unimount'

old_configfile=/etc/config.d/mini_httpd.module.unimount
configfile=/etc/config.d/${module_name}
installfile=/var/run/${module_name}.install
old_deinstallfile=/var/install/deinstall/${old_module_name}
deinstallfile=/var/install/deinstall/${module_name}

# extract shared library file from archive
# to be able to use the myecho command
archivefile=`find /tmp -maxdepth 1 -type l -name "${module_name}.tar.*" ! -name "*.info" | head -n1`

if [ -n "${archivefile}" ]
then
    if [ -s "${archivefile}" ]
    then
        tar xjf ${archivefile} var/install/include/jedlib.${module_name} -C /

        srcfile=/var/install/include/jedlib.${module_name}
        destfile=/var/install/include/jedlib

        if [ -f ${srcfile} ]
        then
            if [ -f ${destfile} ]
            then
                srcver=`/bin/sh ${srcfile} version`
                destver=`/bin/sh ${destfile} version`

                if [ -n "${destver}" ]
                then
                    # version number exists - compare version numbers
                    if [ `echo "${srcver} > ${destver}" | bc` -eq 1 ]
                    then
                        # update file
                        echo "updating shared library file (${destver}->${srcver}) ..."
                        mv -v ${srcfile} ${destfile}
                    fi
                else
                    # no version number exists - update file
                    echo "updating shared library file ..."
                    mv -v ${srcfile} ${destfile}
                fi
            else
                # file doesn't exist - update file
                echo "updating shared library file ..."
                mv -v ${srcfile} ${destfile}
            fi
        fi
    fi
fi

# read eislib etc.
. /var/install/include/eislib
. /var/install/include/jedlib

myecho --pack ${module_name} --info "running preinstall.sh ..."

if [ -f ${old_deinstallfile} ]
then
    myecho --pack ${module_name} "saving previous configuration file to ${installfile} ..."
    cp ${old_configfile} ${installfile}

    # delete legacy package
    myecho --pack ${module_name} "deinstalling previously installed software ..."
    /usr/bin/eisman uninstall --update --auto --quiet ${old_module_name}

    # delete legacy menue entry
    /var/install/bin/del-menu /var/install/bin/setup.services.mini_httpd.module.${old_module_name} \
        /var/install/menu/setup.services.mini_httpd.module.menu
elif [ -f ${deinstallfile} ]
then
    myecho --pack ${module_name} "saving previous configuration file to ${installfile} ..."
    cp ${configfile} ${installfile}

    myecho --pack ${module_name} "deinstalling previously installed software ..."
    /usr/bin/eisman uninstall --update --auto --quiet ${module_name}
fi

exit 0
