#!/bin/sh
#----------------------------------------------------------------------------
# /var/install/bin/mini_httpd_unimount-update.sh - update or generate new
#                                                  configuration
#
# Copyright (c) 2004-2010  Marcus Herleb, herleb(at)herleb(dot)de
# Copyright (c) 2011-2018  The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2011-06-09  jed
# Last Update:  $Id: mini_httpd_unimount-update.sh 52314 2018-03-11 16:25:49Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# read eislib
. /var/install/include/eislib
. /var/install/include/jedlib
. /var/install/include/configlib

# debug mode: true/false
#debug=true
if ${debug:-false}
then
    exec 2>/tmp/$(basename ${0})-trace$$.log
    set -x
    ask_debug=true
    export ask_debug
fi

#------------------------------------------------------------------------------
# function: variable is set
#
# input:  $1 - variable name
# return:  0 - variable set
#          1 - variable not set
#------------------------------------------------------------------------------
variable_set ()
{
    local _vs_var1
    local _vs_var2
    local _vs_ret

    eval _vs_var1=\$"${1}"
    eval _vs_var2=\$"{${1}+EMPTY}"

    if [ -z "${_vs_var1}" ]
    then
        if [ "${_vs_var2}" = 'EMPTY' ]
        then
            # variable is empty, but set
            _vs_ret=0
        else
            # variable is not set
            _vs_ret=1
        fi
    else
        # variable has a value
        _vs_ret=0
    fi

    return ${_vs_ret}
}

#------------------------------------------------------------------------------
# print variable only if it has been set
# $1 - variable name
# $2 - comment
#------------------------------------------------------------------------------
printsetvar ()
{
    if variable_set "${1}"
    then
        printvar "${1}" "${2}"
    fi
}

#------------------------------------------------------------------------------
# rename variables
#------------------------------------------------------------------------------
rename_variables ()
{
    local _rv_renamed
    local _rv_output_file
    local _rv_imax
    local _rv_idx
    local _rv_old_val
    local _rv_new_val
    local _rv_old_uid
    local _rv_new_uid
    local _rv_old_gid
    local _rv_new_gid
    local _rv_old_name
    local _rv_new_name
    local _rv_old_pass
    local _rv_new_pass

    _rv_renamed=0
    _rv_output_file=`mktemp -t ${module_name}.XXXXXXXXX`

    # v0.90.10
    if [ ! -z "`grep ^MOUNT_INFO ${source_conf}`" ]
    then
        echo "- MOUNT_INFO -> UNIMOUNT_INFO" >> ${_rv_output_file}
        UNIMOUNT_INFO="${MOUNT_INFO}"
        _rv_renamed=1
    fi

    if [ ! -z "`grep ^MOUNT_USB ${source_conf}`" ]
    then
        echo "- MOUNT_USB -> UNIMOUNT_USB" >> ${_rv_output_file}
        UNIMOUNT_USB="${MOUNT_USB}"
        _rv_renamed=1
    fi

    if [ ! -z "`grep ^MOUNT_N ${source_conf}`" ]
    then
        echo "- MOUNT_N -> UNIMOUNT_N" >> ${_rv_output_file}
        UNIMOUNT_N="${MOUNT_N}"
        _rv_renamed=1

        # old configuration
        if [ ${MOUNT_N} -eq 0 ]
        then
            _rv_imax=3
        else
            _rv_imax=${MOUNT_N}
        fi
    elif [ ! -z "`grep ^UNIMOUNT_N ${source_conf}`" ]
    then
        # new configuration
        if [ ${UNIMOUNT_N} -eq 0 ]
        then
            _rv_imax=3
        else
            _rv_imax=${UNIMOUNT_N}
        fi
    fi

    _rv_idx=1
    while [ ${_rv_idx} -le ${_rv_imax} ]
    do
        for PNAME in NAME DEVICE POINT OPTION TYPE
        do
            if [ ! -z "`grep ^MOUNT_${_rv_idx}_${PNAME} ${source_conf}`" ]
            then
                eval _rv_old_val='$MOUNT_'${_rv_idx}'_'${PNAME}
                eval _rv_new_val="UNIMOUNT_${_rv_idx}_${PNAME}"

                case ${PNAME} in
                    TYPE )
                        if [ -n "${_rv_old_val}" ]
                        then
                            # set only if not empty
                            echo "- MOUNT_${_rv_idx}_${PNAME} -> UNIMOUNT_${_rv_idx}_${PNAME}" >> ${_rv_output_file}
                            eval "${_rv_new_val}=\"${_rv_old_val}\""
                            _rv_renamed=1
                        fi
                        ;;
                    * )
                        echo "- MOUNT_${_rv_idx}_${PNAME} -> UNIMOUNT_${_rv_idx}_${PNAME}" >> ${_rv_output_file}
                        eval "${_rv_new_val}=\"${_rv_old_val}\""
                        _rv_renamed=1
                        ;;
                esac
            fi
        done

        if [ ! -z "`grep ^MOUNT_${_rv_idx}_UID ${source_conf}`" ]
        then
            eval _rv_old_uid='$MOUNT_'${_rv_idx}'_UID'
            eval _rv_new_uid="UNIMOUNT_${_rv_idx}_USER"

            if [ -n "${uid_val}" ]
            then
                # set only if not empty
                echo "- MOUNT_${_rv_idx}_UID -> UNIMOUNT_${_rv_idx}_USER" >> ${_rv_output_file}
                eval "${_rv_new_uid}=\"${_rv_old_uid}\""
                _rv_renamed=1
            fi
        fi

        if [ ! -z "`grep ^MOUNT_${_rv_idx}_GID ${source_conf}`" ]
        then
            eval _rv_old_gid='$MOUNT_'${_rv_idx}'_GID'
            eval _rv_new_gid="UNIMOUNT_${_rv_idx}_GROUP"

            if [ -n "${gid_val}" ]
            then
                # set only if not empty
                echo "- MOUNT_${_rv_idx}_GID -> UNIMOUNT_${_rv_idx}_GROUP" >> ${_rv_output_file}
                eval "${_rv_new_gid}=\"${_rv_old_gid}\""
                _rv_renamed=1
            fi
        fi

        if [ ! -z "`grep ^MOUNT_${_rv_idx}_USERNAME ${source_conf}`" ]
        then
            eval _rv_old_name='$MOUNT_'${_rv_idx}'_USERNAME'
            eval _rv_new_name="UNIMOUNT_${_rv_idx}_AUTH_USER"

            echo "- MOUNT_${_rv_idx}_USERNAME -> UNIMOUNT_${_rv_idx}_AUTH_USER" >> ${_rv_output_file}
            eval "${_rv_new_name}=\"${_rv_old_name}\""
            _rv_renamed=1
        fi

        if [ ! -z "`grep ^MOUNT_${_rv_idx}_PASSWORD ${source_conf}`" ]
        then
            eval _rv_old_pass='$MOUNT_'${_rv_idx}'_PASSWORD'
            eval _rv_new_pass="UNIMOUNT_${_rv_idx}_AUTH_PASS"

            echo "- MOUNT_${_rv_idx}_PASSWORD -> UNIMOUNT_${_rv_idx}_AUTH_PASS" >> ${_rv_output_file}
            eval "${_rv_new_pass}=\"${_rv_old_pass}\""
            _rv_renamed=1
        fi

        _rv_idx=`expr ${_rv_idx} + 1`
    done

    if [ ${_rv_renamed} -eq 1 ]
    then
        modflag=1
        myecho --pack ${module_name} --force-output "renaming parameter(s) ..."
        cat ${_rv_output_file}
        myecho --pack ${module_name} --force-output --info "... read documentation for renamed parameter(s)!"
    fi

    rm -f ${_rv_output_file}
}

#------------------------------------------------------------------------------
# modify variables
#------------------------------------------------------------------------------
modify_variables ()
{
    local _mv_modified
    local _mv_output_file

    _mv_modified=0
    _mv_output_file=`mktemp -t ${module_name}.XXXXXXXXX`

    if [ ${_mv_modified} -eq 1 ]
    then
        modflag=1
        myecho --pack ${module_name} --force-output "modifying parameter(s) ..."
        cat ${_mv_output_file}
        myecho --pack ${module_name} --force-output --info "... read documentation for modified parameter(s)!"
    fi

    rm -f ${_mv_output_file}
}

#------------------------------------------------------------------------------
# add variables
#------------------------------------------------------------------------------
pre_add_variables ()
{
    local _pav_added
    local _pav_output_file

    _pav_added=0
    _pav_output_file=`mktemp -t ${module_name}.XXXXXXXXX`

    # v0.90.10
    if [ -z "`grep ^START_UNIMOUNT ${source_conf}`" ]
    then
        echo "- START_UNIMOUNT='no'" >> ${_pav_output_file}
        START_UNIMOUNT='no'
        _pav_added=1
    fi

    if [ ${_pav_added} -eq 1 ]
    then
        modflag=1
        myecho --pack ${module_name} --force-output "pre-adding new parameter(s) ..."
        cat ${_pav_output_file}
        myecho --pack ${module_name} --force-output --info "... read documentation for added parameter(s)!"
    fi

    rm -f ${_pav_output_file}
}

#------------------------------------------------------------------------------
# add variables
#------------------------------------------------------------------------------
add_variables ()
{
    local _av_added
    local _av_output_file
    local _av_imax
    local _av_def_answer
    local _av_idx
    local _av_test

    _av_added=0
    _av_output_file=`mktemp -t ${module_name}.XXXXXXXXX`

    # v0.90.10
    if [ -z "${UNIMOUNT_N}" -o ${UNIMOUNT_N} -eq 0 ]
    then
        _av_imax=1
        _av_def_answer='no'
    else
        _av_imax=${UNIMOUNT_N}
        _av_def_answer='yes'
    fi

    _av_idx=1
    while [ ${_av_idx} -le ${_av_imax} ]
    do
        eval _av_test='$UNIMOUNT_'${_av_idx}'_ACTIVE'

        if [ -z "${_av_test}" -a -z "`grep ^UNIMOUNT_${_av_idx}_ACTIVE ${source_conf}`" ]
        then
            echo "- UNIMOUNT_${_av_idx}_ACTIVE='${_av_def_answer}'" >> ${_av_output_file}
            eval "UNIMOUNT_${_av_idx}_ACTIVE='${_av_def_answer}'"
            _av_added=1
        fi

        _av_idx=`expr ${_av_idx} + 1`
    done

    if [ ${_av_added} -eq 1 ]
    then
        modflag=1
        myecho --pack ${module_name} --force-output "adding new parameter(s) ..."
        cat ${_av_output_file}
        myecho --pack ${module_name} --force-output --info "... read documentation for added parameter(s)!"
    fi

    rm -f ${_av_output_file}
}

#------------------------------------------------------------------------------
# delete variables
#------------------------------------------------------------------------------
delete_variables ()
{
    local _dv_deleted
    local _dv_output_file

    _dv_deleted=0
    _dv_output_file=`mktemp -t ${module_name}.XXXXXXXXX`

    if [ ${_dv_deleted} -eq 1 ]
    then
        modflag=1
        myecho --pack ${module_name} "deleting old parameters ..."
        cat ${_dv_output_file}
    fi

    rm -f ${_dv_output_file}
}

#------------------------------------------------------------------------------
# create new configuration
#------------------------------------------------------------------------------
create_config ()
{
    local _cc_imax
    local _cc_idx

    myecho --pack ${module_name} "updating/creating configuration ..."

    {
        #------------------------------------------------------------------------------
        printgpl -conf "${module_name}" "2011-04-18" "jed"
        #------------------------------------------------------------------------------
        #------------------------------------------------------------------------------
        printgroup "general settings"
        #------------------------------------------------------------------------------

        printvar "START_UNIMOUNT"                 "start unimount: yes or no"
        echo
        printvar "UNIMOUNT_INFO"                  "show mount information"
        printvar "UNIMOUNT_USB"                   "allow to mount usb devices"

        #------------------------------------------------------------------------------
        printgroup "mount settings"
        #------------------------------------------------------------------------------

        printvar "UNIMOUNT_N"                       "number of mounts"

        if [ ${UNIMOUNT_N} -eq 0 ]
        then
            _cc_imax=1
        else
            _cc_imax=${UNIMOUNT_N}
        fi

        _cc_idx=1
        while [ ${_cc_idx} -le ${_cc_imax} ]
        do
            echo
            printvar    "UNIMOUNT_${_cc_idx}_ACTIVE"    "${_cc_idx}. activate mount: yes, no"
            printvar    "UNIMOUNT_${_cc_idx}_NAME"      "   name of mount"
            printvar    "UNIMOUNT_${_cc_idx}_DEVICE"    "   name of device"
            printvar    "UNIMOUNT_${_cc_idx}_POINT"     "   mountpoint"
            printvar    "UNIMOUNT_${_cc_idx}_OPTION"    "   mount options"
            printsetvar "UNIMOUNT_${_cc_idx}_USER"      "   user to be used instead of 'root'"
            printsetvar "UNIMOUNT_${_cc_idx}_GROUP"     "   group to be used instead of 'root'"
            printsetvar "UNIMOUNT_${_cc_idx}_TYPE"      "   file system type"
            printsetvar "UNIMOUNT_${_cc_idx}_AUTH_USER" "   authentication name"
            printsetvar "UNIMOUNT_${_cc_idx}_AUTH_PASS" "   authentication password"

            _cc_idx=`expr ${_cc_idx} + 1`
        done

        #------------------------------------------------------------------------------
        printend
        #------------------------------------------------------------------------------
    } > ${generate_conf}
}

#==============================================================================
# main
#==============================================================================

pgmname=`basename $0`
module_name=`basename -s .sh ${pgmname} | cut -d- -f1`

configfile=/etc/config.d/${module_name}
installfile=/var/run/${module_name}.install
defaultfile=/etc/default.d/${module_name}

# setting defaults
source_conf=${installfile}
generate_conf=${configfile}

goflag=0
modflag=0

case $1 in
    *-update|update )
        goflag=1
        ;;
    *-test|test )
        source_conf=${configfile}

        generate_conf=${configfile}.test
        goflag=1
        ;;
    * )
        echo
        echo "Use one of the following options:"
        echo
        echo "  ${module_name}-update.sh [update] - the file ${module_name}.import will be read, the configuration will"
        echo "                                    be checked and an updated mail configuration file will be written."
        echo
        goflag=0
esac

if [ ${goflag} -eq 1 ]
then
    if [ -f ${source_conf} ]
    then
        # previous configuration file exists
        myecho --pack ${module_name} --info "previous configuration found ..."
        . ${source_conf}

        pre_add_variables
        rename_variables
        modify_variables
        add_variables
        delete_variables

        create_config
    else
        myecho --pack ${module_name} --error "no configuration ${source_conf} found - exiting."
        myanykey --pack ${module_name}
    fi
fi

#==============================================================================
# end
#==============================================================================
exit 0
