#!/bin/sh
#-------------------------------------------------------------------------------
# /var/install/config.d/mini_httpd_unimount.sh - configuration generator script
#
# Copyright (c) 2004-2010 Marcus Herleb, herleb(at)herleb(dot)de
# Copyright (c) 2011-2018  The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2011-06-09 jed
# Last Update:  $Id: mini_httpd_unimount.sh 52314 2018-03-11 16:25:49Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version..
#------------------------------------------------------------------------------

# read eislib
. /var/install/include/eislib
. /var/install/include/jedlib

# debug mode: true/false
#debug=true
if ${debug:-false}
then
    exec 2>/tmp/$(basename ${0})-trace$$.log
    set -x
    ask_debug=true
    export ask_debug
fi

pgmname=`basename $0`
module_name=`basename -s .sh ${pgmname} | cut -d- -f1`

config_file=/etc/config.d/${module_name}
package_file=/var/install/packages/${module_name}

if [ -f ${package_file} ]
then
    package_version="v`grep "<version>" ${package_file} | sed 's#<version>\(.*\)</version>#\1#'`"
else
    package_version="version could not be read"
fi

### load configuration ###
. ${config_file}
chmod 0600 ${config_file}

#========================================================================================
# main
#========================================================================================

case $1 in
    * )
        # generate all configuration files
        myecho --pack ${module_name} ""
        myecho --pack ${module_name} "${module_name} version: ${package_version}"

        if [ "${START_UNIMOUNT}" = 'yes' ]
        then
            myecho --pack ${module_name} "package enabled!"
        else
            myecho --pack ${module_name} --warn "configuration has been disabled!"
        fi

        myecho --pack ${module_name} "finished."
        ;;
esac

#========================================================================================
# End
#========================================================================================
exit 0
